Index: net/ssl/ssl_config.h |
diff --git a/net/ssl/ssl_config.h b/net/ssl/ssl_config.h |
index 9a73f41afd631312ac8da8332f41d62f64a17dd7..cd83ea5d797402e141fe23180e1cdbb3082e328a 100644 |
--- a/net/ssl/ssl_config.h |
+++ b/net/ssl/ssl_config.h |
@@ -154,13 +154,20 @@ struct NET_EXPORT SSLConfig { |
// NOTE: Only used by NSS. |
bool cert_io_enabled; |
- // The list of supported application level protocols supported in decreasing |
- // order of preference. For ALPN (Application Layer Protocol Negotation), |
- // protocols will be advertised in this order. For NPN (Next Protocol |
- // Negotiation), the last item on the list is selected if there is no overlap |
- // between |next_protos| and the protocols supported by the server, otherwise |
- // server preference is observed and the order of |next_protos| is irrelevant. |
- NextProtoVector next_protos; |
+ // The list of application level protocols supported with ALPN (Application |
+ // Layer Protocol Negotation), in decreasing order of preference. Protocols |
+ // will be advertised in this order during TLS handshake. |
+ NextProtoVector alpn_protos; |
+ |
+ // The list of application level protocols supported with NPN (Next Protocol |
+ // Negotiation). The last item on the list is selected if there is no overlap |
+ // between |npn_protos| and the protocols supported by the server, otherwise |
+ // server preference is observed and the order of |npn_protos| is irrelevant. |
+ // Note that due to NSS limitations, ports which use NSS will use |
+ // |alpn_protos| for both ALPN and NPN. However, if |npn_protos| is empty, NPN |
+ // will still be disabled. |
+ // TODO(bnc): Deprecate NPN, see https://crbug.com/526713. |
+ NextProtoVector npn_protos; |
// True if renegotiation should be allowed for the default application-level |
// protocol when the peer negotiates neither ALPN nor NPN. |